# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szconfigmanager.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szconfigmanager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15szconfigmanager.proto\x12\x0fszconfigmanager\"%\n\x10GetConfigRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"#\n\x11GetConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1a\n\x18GetConfigRegistryRequest\"+\n\x19GetConfigRegistryResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1b\n\x19GetDefaultConfigIdRequest\",\n\x1aGetDefaultConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"\x1a\n\x18GetTemplateConfigRequest\"+\n\x19GetTemplateConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"J\n\x15RegisterConfigRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_comment\x18\x02 \x01(\t\"(\n\x16RegisterConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"a\n\x1dReplaceDefaultConfigIdRequest\x12!\n\x19\x63urrent_default_config_id\x18\x01 \x01(\x03\x12\x1d\n\x15new_default_config_id\x18\x02 \x01(\x03\" \n\x1eReplaceDefaultConfigIdResponse\"L\n\x17SetDefaultConfigRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_comment\x18\x02 \x01(\t\"*\n\x18SetDefaultConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\".\n\x19SetDefaultConfigIdRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"\x1c\n\x1aSetDefaultConfigIdResponse2\xf2\x06\n\x0fSzConfigManager\x12T\n\tGetConfig\x12!.szconfigmanager.GetConfigRequest\x1a\".szconfigmanager.GetConfigResponse\"\x00\x12l\n\x11GetConfigRegistry\x12).szconfigmanager.GetConfigRegistryRequest\x1a*.szconfigmanager.GetConfigRegistryResponse\"\x00\x12o\n\x12GetDefaultConfigId\x12*.szconfigmanager.GetDefaultConfigIdRequest\x1a+.szconfigmanager.GetDefaultConfigIdResponse\"\x00\x12l\n\x11GetTemplateConfig\x12).szconfigmanager.GetTemplateConfigRequest\x1a*.szconfigmanager.GetTemplateConfigResponse\"\x00\x12\x63\n\x0eRegisterConfig\x12&.szconfigmanager.RegisterConfigRequest\x1a\'.szconfigmanager.RegisterConfigResponse\"\x00\x12{\n\x16ReplaceDefaultConfigId\x12..szconfigmanager.ReplaceDefaultConfigIdRequest\x1a/.szconfigmanager.ReplaceDefaultConfigIdResponse\"\x00\x12i\n\x10SetDefaultConfig\x12(.szconfigmanager.SetDefaultConfigRequest\x1a).szconfigmanager.SetDefaultConfigResponse\"\x00\x12o\n\x12SetDefaultConfigId\x12*.szconfigmanager.SetDefaultConfigIdRequest\x1a+.szconfigmanager.SetDefaultConfigIdResponse\"\x00\x42\x66\n\x14\x63om.senzing.sdk.grpcB\x14SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szconfigmanager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\024SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanager'
  _globals['_GETCONFIGREQUEST']._serialized_start=42
  _globals['_GETCONFIGREQUEST']._serialized_end=79
  _globals['_GETCONFIGRESPONSE']._serialized_start=81
  _globals['_GETCONFIGRESPONSE']._serialized_end=116
  _globals['_GETCONFIGREGISTRYREQUEST']._serialized_start=118
  _globals['_GETCONFIGREGISTRYREQUEST']._serialized_end=144
  _globals['_GETCONFIGREGISTRYRESPONSE']._serialized_start=146
  _globals['_GETCONFIGREGISTRYRESPONSE']._serialized_end=189
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_start=191
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_end=218
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_start=220
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_end=264
  _globals['_GETTEMPLATECONFIGREQUEST']._serialized_start=266
  _globals['_GETTEMPLATECONFIGREQUEST']._serialized_end=292
  _globals['_GETTEMPLATECONFIGRESPONSE']._serialized_start=294
  _globals['_GETTEMPLATECONFIGRESPONSE']._serialized_end=337
  _globals['_REGISTERCONFIGREQUEST']._serialized_start=339
  _globals['_REGISTERCONFIGREQUEST']._serialized_end=413
  _globals['_REGISTERCONFIGRESPONSE']._serialized_start=415
  _globals['_REGISTERCONFIGRESPONSE']._serialized_end=455
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_start=457
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_end=554
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_start=556
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_end=588
  _globals['_SETDEFAULTCONFIGREQUEST']._serialized_start=590
  _globals['_SETDEFAULTCONFIGREQUEST']._serialized_end=666
  _globals['_SETDEFAULTCONFIGRESPONSE']._serialized_start=668
  _globals['_SETDEFAULTCONFIGRESPONSE']._serialized_end=710
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_start=712
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_end=758
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_start=760
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_end=788
  _globals['_SZCONFIGMANAGER']._serialized_start=791
  _globals['_SZCONFIGMANAGER']._serialized_end=1673
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szconfigmanager_pb2 as szconfigmanager__pb2

GRPC_GENERATED_VERSION = "1.73.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in szconfigmanager_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class SzConfigManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConfig = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/GetConfig",
            request_serializer=szconfigmanager__pb2.GetConfigRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.GetConfigResponse.FromString,
            _registered_method=True,
        )
        self.GetConfigRegistry = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/GetConfigRegistry",
            request_serializer=szconfigmanager__pb2.GetConfigRegistryRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.GetConfigRegistryResponse.FromString,
            _registered_method=True,
        )
        self.GetDefaultConfigId = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/GetDefaultConfigId",
            request_serializer=szconfigmanager__pb2.GetDefaultConfigIdRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.GetDefaultConfigIdResponse.FromString,
            _registered_method=True,
        )
        self.GetTemplateConfig = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/GetTemplateConfig",
            request_serializer=szconfigmanager__pb2.GetTemplateConfigRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.GetTemplateConfigResponse.FromString,
            _registered_method=True,
        )
        self.RegisterConfig = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/RegisterConfig",
            request_serializer=szconfigmanager__pb2.RegisterConfigRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.RegisterConfigResponse.FromString,
            _registered_method=True,
        )
        self.ReplaceDefaultConfigId = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/ReplaceDefaultConfigId",
            request_serializer=szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.FromString,
            _registered_method=True,
        )
        self.SetDefaultConfig = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/SetDefaultConfig",
            request_serializer=szconfigmanager__pb2.SetDefaultConfigRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.SetDefaultConfigResponse.FromString,
            _registered_method=True,
        )
        self.SetDefaultConfigId = channel.unary_unary(
            "/szconfigmanager.SzConfigManager/SetDefaultConfigId",
            request_serializer=szconfigmanager__pb2.SetDefaultConfigIdRequest.SerializeToString,
            response_deserializer=szconfigmanager__pb2.SetDefaultConfigIdResponse.FromString,
            _registered_method=True,
        )


class SzConfigManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetConfigRegistry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTemplateConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RegisterConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReplaceDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetDefaultConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetDefaultConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SzConfigManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetConfig": grpc.unary_unary_rpc_method_handler(
            servicer.GetConfig,
            request_deserializer=szconfigmanager__pb2.GetConfigRequest.FromString,
            response_serializer=szconfigmanager__pb2.GetConfigResponse.SerializeToString,
        ),
        "GetConfigRegistry": grpc.unary_unary_rpc_method_handler(
            servicer.GetConfigRegistry,
            request_deserializer=szconfigmanager__pb2.GetConfigRegistryRequest.FromString,
            response_serializer=szconfigmanager__pb2.GetConfigRegistryResponse.SerializeToString,
        ),
        "GetDefaultConfigId": grpc.unary_unary_rpc_method_handler(
            servicer.GetDefaultConfigId,
            request_deserializer=szconfigmanager__pb2.GetDefaultConfigIdRequest.FromString,
            response_serializer=szconfigmanager__pb2.GetDefaultConfigIdResponse.SerializeToString,
        ),
        "GetTemplateConfig": grpc.unary_unary_rpc_method_handler(
            servicer.GetTemplateConfig,
            request_deserializer=szconfigmanager__pb2.GetTemplateConfigRequest.FromString,
            response_serializer=szconfigmanager__pb2.GetTemplateConfigResponse.SerializeToString,
        ),
        "RegisterConfig": grpc.unary_unary_rpc_method_handler(
            servicer.RegisterConfig,
            request_deserializer=szconfigmanager__pb2.RegisterConfigRequest.FromString,
            response_serializer=szconfigmanager__pb2.RegisterConfigResponse.SerializeToString,
        ),
        "ReplaceDefaultConfigId": grpc.unary_unary_rpc_method_handler(
            servicer.ReplaceDefaultConfigId,
            request_deserializer=szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.FromString,
            response_serializer=szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.SerializeToString,
        ),
        "SetDefaultConfig": grpc.unary_unary_rpc_method_handler(
            servicer.SetDefaultConfig,
            request_deserializer=szconfigmanager__pb2.SetDefaultConfigRequest.FromString,
            response_serializer=szconfigmanager__pb2.SetDefaultConfigResponse.SerializeToString,
        ),
        "SetDefaultConfigId": grpc.unary_unary_rpc_method_handler(
            servicer.SetDefaultConfigId,
            request_deserializer=szconfigmanager__pb2.SetDefaultConfigIdRequest.FromString,
            response_serializer=szconfigmanager__pb2.SetDefaultConfigIdResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("szconfigmanager.SzConfigManager", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("szconfigmanager.SzConfigManager", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class SzConfigManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/GetConfig",
            szconfigmanager__pb2.GetConfigRequest.SerializeToString,
            szconfigmanager__pb2.GetConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetConfigRegistry(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/GetConfigRegistry",
            szconfigmanager__pb2.GetConfigRegistryRequest.SerializeToString,
            szconfigmanager__pb2.GetConfigRegistryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetDefaultConfigId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/GetDefaultConfigId",
            szconfigmanager__pb2.GetDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.GetDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetTemplateConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/GetTemplateConfig",
            szconfigmanager__pb2.GetTemplateConfigRequest.SerializeToString,
            szconfigmanager__pb2.GetTemplateConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def RegisterConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/RegisterConfig",
            szconfigmanager__pb2.RegisterConfigRequest.SerializeToString,
            szconfigmanager__pb2.RegisterConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ReplaceDefaultConfigId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/ReplaceDefaultConfigId",
            szconfigmanager__pb2.ReplaceDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.ReplaceDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SetDefaultConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/SetDefaultConfig",
            szconfigmanager__pb2.SetDefaultConfigRequest.SerializeToString,
            szconfigmanager__pb2.SetDefaultConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SetDefaultConfigId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szconfigmanager.SzConfigManager/SetDefaultConfigId",
            szconfigmanager__pb2.SetDefaultConfigIdRequest.SerializeToString,
            szconfigmanager__pb2.SetDefaultConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szproduct.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szproduct.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fszproduct.proto\x12\tszproduct\"\x13\n\x11GetLicenseRequest\"$\n\x12GetLicenseResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x13\n\x11GetVersionRequest\"$\n\x12GetVersionResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\xa5\x01\n\tSzProduct\x12K\n\nGetLicense\x12\x1c.szproduct.GetLicenseRequest\x1a\x1d.szproduct.GetLicenseResponse\"\x00\x12K\n\nGetVersion\x12\x1c.szproduct.GetVersionRequest\x1a\x1d.szproduct.GetVersionResponse\"\x00\x42Z\n\x14\x63om.senzing.sdk.grpcB\x0eSzProductProtoZ2github.com/senzing-garage/sz-sdk-go-grpc/szproductb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szproduct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\016SzProductProtoZ2github.com/senzing-garage/sz-sdk-go-grpc/szproduct'
  _globals['_GETLICENSEREQUEST']._serialized_start=30
  _globals['_GETLICENSEREQUEST']._serialized_end=49
  _globals['_GETLICENSERESPONSE']._serialized_start=51
  _globals['_GETLICENSERESPONSE']._serialized_end=87
  _globals['_GETVERSIONREQUEST']._serialized_start=89
  _globals['_GETVERSIONREQUEST']._serialized_end=108
  _globals['_GETVERSIONRESPONSE']._serialized_start=110
  _globals['_GETVERSIONRESPONSE']._serialized_end=146
  _globals['_SZPRODUCT']._serialized_start=149
  _globals['_SZPRODUCT']._serialized_end=314
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szdiagnostic_pb2 as szdiagnostic__pb2

GRPC_GENERATED_VERSION = "1.73.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in szdiagnostic_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class SzDiagnosticStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CheckDatastorePerformance = channel.unary_unary(
            "/szdiagnostic.SzDiagnostic/CheckDatastorePerformance",
            request_serializer=szdiagnostic__pb2.CheckDatastorePerformanceRequest.SerializeToString,
            response_deserializer=szdiagnostic__pb2.CheckDatastorePerformanceResponse.FromString,
            _registered_method=True,
        )
        self.GetDatastoreInfo = channel.unary_unary(
            "/szdiagnostic.SzDiagnostic/GetDatastoreInfo",
            request_serializer=szdiagnostic__pb2.GetDatastoreInfoRequest.SerializeToString,
            response_deserializer=szdiagnostic__pb2.GetDatastoreInfoResponse.FromString,
            _registered_method=True,
        )
        self.GetFeature = channel.unary_unary(
            "/szdiagnostic.SzDiagnostic/GetFeature",
            request_serializer=szdiagnostic__pb2.GetFeatureRequest.SerializeToString,
            response_deserializer=szdiagnostic__pb2.GetFeatureResponse.FromString,
            _registered_method=True,
        )
        self.PurgeRepository = channel.unary_unary(
            "/szdiagnostic.SzDiagnostic/PurgeRepository",
            request_serializer=szdiagnostic__pb2.PurgeRepositoryRequest.SerializeToString,
            response_deserializer=szdiagnostic__pb2.PurgeRepositoryResponse.FromString,
            _registered_method=True,
        )
        self.Reinitialize = channel.unary_unary(
            "/szdiagnostic.SzDiagnostic/Reinitialize",
            request_serializer=szdiagnostic__pb2.ReinitializeRequest.SerializeToString,
            response_deserializer=szdiagnostic__pb2.ReinitializeResponse.FromString,
            _registered_method=True,
        )


class SzDiagnosticServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CheckDatastorePerformance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDatastoreInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PurgeRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Reinitialize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SzDiagnosticServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CheckDatastorePerformance": grpc.unary_unary_rpc_method_handler(
            servicer.CheckDatastorePerformance,
            request_deserializer=szdiagnostic__pb2.CheckDatastorePerformanceRequest.FromString,
            response_serializer=szdiagnostic__pb2.CheckDatastorePerformanceResponse.SerializeToString,
        ),
        "GetDatastoreInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetDatastoreInfo,
            request_deserializer=szdiagnostic__pb2.GetDatastoreInfoRequest.FromString,
            response_serializer=szdiagnostic__pb2.GetDatastoreInfoResponse.SerializeToString,
        ),
        "GetFeature": grpc.unary_unary_rpc_method_handler(
            servicer.GetFeature,
            request_deserializer=szdiagnostic__pb2.GetFeatureRequest.FromString,
            response_serializer=szdiagnostic__pb2.GetFeatureResponse.SerializeToString,
        ),
        "PurgeRepository": grpc.unary_unary_rpc_method_handler(
            servicer.PurgeRepository,
            request_deserializer=szdiagnostic__pb2.PurgeRepositoryRequest.FromString,
            response_serializer=szdiagnostic__pb2.PurgeRepositoryResponse.SerializeToString,
        ),
        "Reinitialize": grpc.unary_unary_rpc_method_handler(
            servicer.Reinitialize,
            request_deserializer=szdiagnostic__pb2.ReinitializeRequest.FromString,
            response_serializer=szdiagnostic__pb2.ReinitializeResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("szdiagnostic.SzDiagnostic", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("szdiagnostic.SzDiagnostic", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class SzDiagnostic(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CheckDatastorePerformance(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szdiagnostic.SzDiagnostic/CheckDatastorePerformance",
            szdiagnostic__pb2.CheckDatastorePerformanceRequest.SerializeToString,
            szdiagnostic__pb2.CheckDatastorePerformanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetDatastoreInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szdiagnostic.SzDiagnostic/GetDatastoreInfo",
            szdiagnostic__pb2.GetDatastoreInfoRequest.SerializeToString,
            szdiagnostic__pb2.GetDatastoreInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetFeature(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szdiagnostic.SzDiagnostic/GetFeature",
            szdiagnostic__pb2.GetFeatureRequest.SerializeToString,
            szdiagnostic__pb2.GetFeatureResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def PurgeRepository(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szdiagnostic.SzDiagnostic/PurgeRepository",
            szdiagnostic__pb2.PurgeRepositoryRequest.SerializeToString,
            szdiagnostic__pb2.PurgeRepositoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Reinitialize(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szdiagnostic.SzDiagnostic/Reinitialize",
            szdiagnostic__pb2.ReinitializeRequest.SerializeToString,
            szdiagnostic__pb2.ReinitializeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szengine_pb2 as szengine__pb2

GRPC_GENERATED_VERSION = "1.73.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in szengine_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class SzEngineStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddRecord = channel.unary_unary(
            "/szengine.SzEngine/AddRecord",
            request_serializer=szengine__pb2.AddRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.AddRecordResponse.FromString,
            _registered_method=True,
        )
        self.CloseExport = channel.unary_unary(
            "/szengine.SzEngine/CloseExport",
            request_serializer=szengine__pb2.CloseExportRequest.SerializeToString,
            response_deserializer=szengine__pb2.CloseExportResponse.FromString,
            _registered_method=True,
        )
        self.CountRedoRecords = channel.unary_unary(
            "/szengine.SzEngine/CountRedoRecords",
            request_serializer=szengine__pb2.CountRedoRecordsRequest.SerializeToString,
            response_deserializer=szengine__pb2.CountRedoRecordsResponse.FromString,
            _registered_method=True,
        )
        self.DeleteRecord = channel.unary_unary(
            "/szengine.SzEngine/DeleteRecord",
            request_serializer=szengine__pb2.DeleteRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.DeleteRecordResponse.FromString,
            _registered_method=True,
        )
        self.ExportCsvEntityReport = channel.unary_unary(
            "/szengine.SzEngine/ExportCsvEntityReport",
            request_serializer=szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
            response_deserializer=szengine__pb2.ExportCsvEntityReportResponse.FromString,
            _registered_method=True,
        )
        self.ExportJsonEntityReport = channel.unary_unary(
            "/szengine.SzEngine/ExportJsonEntityReport",
            request_serializer=szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
            response_deserializer=szengine__pb2.ExportJsonEntityReportResponse.FromString,
            _registered_method=True,
        )
        self.FetchNext = channel.unary_unary(
            "/szengine.SzEngine/FetchNext",
            request_serializer=szengine__pb2.FetchNextRequest.SerializeToString,
            response_deserializer=szengine__pb2.FetchNextResponse.FromString,
            _registered_method=True,
        )
        self.FindInterestingEntitiesByEntityId = channel.unary_unary(
            "/szengine.SzEngine/FindInterestingEntitiesByEntityId",
            request_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
            _registered_method=True,
        )
        self.FindInterestingEntitiesByRecordId = channel.unary_unary(
            "/szengine.SzEngine/FindInterestingEntitiesByRecordId",
            request_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
            _registered_method=True,
        )
        self.FindNetworkByEntityId = channel.unary_unary(
            "/szengine.SzEngine/FindNetworkByEntityId",
            request_serializer=szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindNetworkByEntityIdResponse.FromString,
            _registered_method=True,
        )
        self.FindNetworkByRecordId = channel.unary_unary(
            "/szengine.SzEngine/FindNetworkByRecordId",
            request_serializer=szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindNetworkByRecordIdResponse.FromString,
            _registered_method=True,
        )
        self.FindPathByEntityId = channel.unary_unary(
            "/szengine.SzEngine/FindPathByEntityId",
            request_serializer=szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindPathByEntityIdResponse.FromString,
            _registered_method=True,
        )
        self.FindPathByRecordId = channel.unary_unary(
            "/szengine.SzEngine/FindPathByRecordId",
            request_serializer=szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.FindPathByRecordIdResponse.FromString,
            _registered_method=True,
        )
        self.GetActiveConfigId = channel.unary_unary(
            "/szengine.SzEngine/GetActiveConfigId",
            request_serializer=szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetActiveConfigIdResponse.FromString,
            _registered_method=True,
        )
        self.GetEntityByEntityId = channel.unary_unary(
            "/szengine.SzEngine/GetEntityByEntityId",
            request_serializer=szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetEntityByEntityIdResponse.FromString,
            _registered_method=True,
        )
        self.GetEntityByRecordId = channel.unary_unary(
            "/szengine.SzEngine/GetEntityByRecordId",
            request_serializer=szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetEntityByRecordIdResponse.FromString,
            _registered_method=True,
        )
        self.GetRecord = channel.unary_unary(
            "/szengine.SzEngine/GetRecord",
            request_serializer=szengine__pb2.GetRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetRecordResponse.FromString,
            _registered_method=True,
        )
        self.GetRedoRecord = channel.unary_unary(
            "/szengine.SzEngine/GetRedoRecord",
            request_serializer=szengine__pb2.GetRedoRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetRedoRecordResponse.FromString,
            _registered_method=True,
        )
        self.GetStats = channel.unary_unary(
            "/szengine.SzEngine/GetStats",
            request_serializer=szengine__pb2.GetStatsRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetStatsResponse.FromString,
            _registered_method=True,
        )
        self.GetVirtualEntityByRecordId = channel.unary_unary(
            "/szengine.SzEngine/GetVirtualEntityByRecordId",
            request_serializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
            _registered_method=True,
        )
        self.HowEntityByEntityId = channel.unary_unary(
            "/szengine.SzEngine/HowEntityByEntityId",
            request_serializer=szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
            response_deserializer=szengine__pb2.HowEntityByEntityIdResponse.FromString,
            _registered_method=True,
        )
        self.PreprocessRecord = channel.unary_unary(
            "/szengine.SzEngine/PreprocessRecord",
            request_serializer=szengine__pb2.PreprocessRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.PreprocessRecordResponse.FromString,
            _registered_method=True,
        )
        self.PrimeEngine = channel.unary_unary(
            "/szengine.SzEngine/PrimeEngine",
            request_serializer=szengine__pb2.PrimeEngineRequest.SerializeToString,
            response_deserializer=szengine__pb2.PrimeEngineResponse.FromString,
            _registered_method=True,
        )
        self.ProcessRedoRecord = channel.unary_unary(
            "/szengine.SzEngine/ProcessRedoRecord",
            request_serializer=szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.ProcessRedoRecordResponse.FromString,
            _registered_method=True,
        )
        self.ReevaluateEntity = channel.unary_unary(
            "/szengine.SzEngine/ReevaluateEntity",
            request_serializer=szengine__pb2.ReevaluateEntityRequest.SerializeToString,
            response_deserializer=szengine__pb2.ReevaluateEntityResponse.FromString,
            _registered_method=True,
        )
        self.ReevaluateRecord = channel.unary_unary(
            "/szengine.SzEngine/ReevaluateRecord",
            request_serializer=szengine__pb2.ReevaluateRecordRequest.SerializeToString,
            response_deserializer=szengine__pb2.ReevaluateRecordResponse.FromString,
            _registered_method=True,
        )
        self.Reinitialize = channel.unary_unary(
            "/szengine.SzEngine/Reinitialize",
            request_serializer=szengine__pb2.ReinitializeRequest.SerializeToString,
            response_deserializer=szengine__pb2.ReinitializeResponse.FromString,
            _registered_method=True,
        )
        self.SearchByAttributes = channel.unary_unary(
            "/szengine.SzEngine/SearchByAttributes",
            request_serializer=szengine__pb2.SearchByAttributesRequest.SerializeToString,
            response_deserializer=szengine__pb2.SearchByAttributesResponse.FromString,
            _registered_method=True,
        )
        self.StreamExportCsvEntityReport = channel.unary_stream(
            "/szengine.SzEngine/StreamExportCsvEntityReport",
            request_serializer=szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
            response_deserializer=szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
            _registered_method=True,
        )
        self.StreamExportJsonEntityReport = channel.unary_stream(
            "/szengine.SzEngine/StreamExportJsonEntityReport",
            request_serializer=szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
            response_deserializer=szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
            _registered_method=True,
        )
        self.WhyEntities = channel.unary_unary(
            "/szengine.SzEngine/WhyEntities",
            request_serializer=szengine__pb2.WhyEntitiesRequest.SerializeToString,
            response_deserializer=szengine__pb2.WhyEntitiesResponse.FromString,
            _registered_method=True,
        )
        self.WhyRecordInEntity = channel.unary_unary(
            "/szengine.SzEngine/WhyRecordInEntity",
            request_serializer=szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
            response_deserializer=szengine__pb2.WhyRecordInEntityResponse.FromString,
            _registered_method=True,
        )
        self.WhyRecords = channel.unary_unary(
            "/szengine.SzEngine/WhyRecords",
            request_serializer=szengine__pb2.WhyRecordsRequest.SerializeToString,
            response_deserializer=szengine__pb2.WhyRecordsResponse.FromString,
            _registered_method=True,
        )
        self.WhySearch = channel.unary_unary(
            "/szengine.SzEngine/WhySearch",
            request_serializer=szengine__pb2.WhySearchRequest.SerializeToString,
            response_deserializer=szengine__pb2.WhySearchResponse.FromString,
            _registered_method=True,
        )


class SzEngineServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CloseExport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CountRedoRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FetchNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindInterestingEntitiesByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindInterestingEntitiesByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindNetworkByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FindPathByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetActiveConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVirtualEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HowEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PreprocessRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PrimeEngine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProcessRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReevaluateRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Reinitialize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchByAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyEntities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyRecordInEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhyRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WhySearch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SzEngineServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AddRecord": grpc.unary_unary_rpc_method_handler(
            servicer.AddRecord,
            request_deserializer=szengine__pb2.AddRecordRequest.FromString,
            response_serializer=szengine__pb2.AddRecordResponse.SerializeToString,
        ),
        "CloseExport": grpc.unary_unary_rpc_method_handler(
            servicer.CloseExport,
            request_deserializer=szengine__pb2.CloseExportRequest.FromString,
            response_serializer=szengine__pb2.CloseExportResponse.SerializeToString,
        ),
        "CountRedoRecords": grpc.unary_unary_rpc_method_handler(
            servicer.CountRedoRecords,
            request_deserializer=szengine__pb2.CountRedoRecordsRequest.FromString,
            response_serializer=szengine__pb2.CountRedoRecordsResponse.SerializeToString,
        ),
        "DeleteRecord": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteRecord,
            request_deserializer=szengine__pb2.DeleteRecordRequest.FromString,
            response_serializer=szengine__pb2.DeleteRecordResponse.SerializeToString,
        ),
        "ExportCsvEntityReport": grpc.unary_unary_rpc_method_handler(
            servicer.ExportCsvEntityReport,
            request_deserializer=szengine__pb2.ExportCsvEntityReportRequest.FromString,
            response_serializer=szengine__pb2.ExportCsvEntityReportResponse.SerializeToString,
        ),
        "ExportJsonEntityReport": grpc.unary_unary_rpc_method_handler(
            servicer.ExportJsonEntityReport,
            request_deserializer=szengine__pb2.ExportJsonEntityReportRequest.FromString,
            response_serializer=szengine__pb2.ExportJsonEntityReportResponse.SerializeToString,
        ),
        "FetchNext": grpc.unary_unary_rpc_method_handler(
            servicer.FetchNext,
            request_deserializer=szengine__pb2.FetchNextRequest.FromString,
            response_serializer=szengine__pb2.FetchNextResponse.SerializeToString,
        ),
        "FindInterestingEntitiesByEntityId": grpc.unary_unary_rpc_method_handler(
            servicer.FindInterestingEntitiesByEntityId,
            request_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.FromString,
            response_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.SerializeToString,
        ),
        "FindInterestingEntitiesByRecordId": grpc.unary_unary_rpc_method_handler(
            servicer.FindInterestingEntitiesByRecordId,
            request_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.FromString,
            response_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.SerializeToString,
        ),
        "FindNetworkByEntityId": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByEntityId,
            request_deserializer=szengine__pb2.FindNetworkByEntityIdRequest.FromString,
            response_serializer=szengine__pb2.FindNetworkByEntityIdResponse.SerializeToString,
        ),
        "FindNetworkByRecordId": grpc.unary_unary_rpc_method_handler(
            servicer.FindNetworkByRecordId,
            request_deserializer=szengine__pb2.FindNetworkByRecordIdRequest.FromString,
            response_serializer=szengine__pb2.FindNetworkByRecordIdResponse.SerializeToString,
        ),
        "FindPathByEntityId": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByEntityId,
            request_deserializer=szengine__pb2.FindPathByEntityIdRequest.FromString,
            response_serializer=szengine__pb2.FindPathByEntityIdResponse.SerializeToString,
        ),
        "FindPathByRecordId": grpc.unary_unary_rpc_method_handler(
            servicer.FindPathByRecordId,
            request_deserializer=szengine__pb2.FindPathByRecordIdRequest.FromString,
            response_serializer=szengine__pb2.FindPathByRecordIdResponse.SerializeToString,
        ),
        "GetActiveConfigId": grpc.unary_unary_rpc_method_handler(
            servicer.GetActiveConfigId,
            request_deserializer=szengine__pb2.GetActiveConfigIdRequest.FromString,
            response_serializer=szengine__pb2.GetActiveConfigIdResponse.SerializeToString,
        ),
        "GetEntityByEntityId": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByEntityId,
            request_deserializer=szengine__pb2.GetEntityByEntityIdRequest.FromString,
            response_serializer=szengine__pb2.GetEntityByEntityIdResponse.SerializeToString,
        ),
        "GetEntityByRecordId": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntityByRecordId,
            request_deserializer=szengine__pb2.GetEntityByRecordIdRequest.FromString,
            response_serializer=szengine__pb2.GetEntityByRecordIdResponse.SerializeToString,
        ),
        "GetRecord": grpc.unary_unary_rpc_method_handler(
            servicer.GetRecord,
            request_deserializer=szengine__pb2.GetRecordRequest.FromString,
            response_serializer=szengine__pb2.GetRecordResponse.SerializeToString,
        ),
        "GetRedoRecord": grpc.unary_unary_rpc_method_handler(
            servicer.GetRedoRecord,
            request_deserializer=szengine__pb2.GetRedoRecordRequest.FromString,
            response_serializer=szengine__pb2.GetRedoRecordResponse.SerializeToString,
        ),
        "GetStats": grpc.unary_unary_rpc_method_handler(
            servicer.GetStats,
            request_deserializer=szengine__pb2.GetStatsRequest.FromString,
            response_serializer=szengine__pb2.GetStatsResponse.SerializeToString,
        ),
        "GetVirtualEntityByRecordId": grpc.unary_unary_rpc_method_handler(
            servicer.GetVirtualEntityByRecordId,
            request_deserializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.FromString,
            response_serializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.SerializeToString,
        ),
        "HowEntityByEntityId": grpc.unary_unary_rpc_method_handler(
            servicer.HowEntityByEntityId,
            request_deserializer=szengine__pb2.HowEntityByEntityIdRequest.FromString,
            response_serializer=szengine__pb2.HowEntityByEntityIdResponse.SerializeToString,
        ),
        "PreprocessRecord": grpc.unary_unary_rpc_method_handler(
            servicer.PreprocessRecord,
            request_deserializer=szengine__pb2.PreprocessRecordRequest.FromString,
            response_serializer=szengine__pb2.PreprocessRecordResponse.SerializeToString,
        ),
        "PrimeEngine": grpc.unary_unary_rpc_method_handler(
            servicer.PrimeEngine,
            request_deserializer=szengine__pb2.PrimeEngineRequest.FromString,
            response_serializer=szengine__pb2.PrimeEngineResponse.SerializeToString,
        ),
        "ProcessRedoRecord": grpc.unary_unary_rpc_method_handler(
            servicer.ProcessRedoRecord,
            request_deserializer=szengine__pb2.ProcessRedoRecordRequest.FromString,
            response_serializer=szengine__pb2.ProcessRedoRecordResponse.SerializeToString,
        ),
        "ReevaluateEntity": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateEntity,
            request_deserializer=szengine__pb2.ReevaluateEntityRequest.FromString,
            response_serializer=szengine__pb2.ReevaluateEntityResponse.SerializeToString,
        ),
        "ReevaluateRecord": grpc.unary_unary_rpc_method_handler(
            servicer.ReevaluateRecord,
            request_deserializer=szengine__pb2.ReevaluateRecordRequest.FromString,
            response_serializer=szengine__pb2.ReevaluateRecordResponse.SerializeToString,
        ),
        "Reinitialize": grpc.unary_unary_rpc_method_handler(
            servicer.Reinitialize,
            request_deserializer=szengine__pb2.ReinitializeRequest.FromString,
            response_serializer=szengine__pb2.ReinitializeResponse.SerializeToString,
        ),
        "SearchByAttributes": grpc.unary_unary_rpc_method_handler(
            servicer.SearchByAttributes,
            request_deserializer=szengine__pb2.SearchByAttributesRequest.FromString,
            response_serializer=szengine__pb2.SearchByAttributesResponse.SerializeToString,
        ),
        "StreamExportCsvEntityReport": grpc.unary_stream_rpc_method_handler(
            servicer.StreamExportCsvEntityReport,
            request_deserializer=szengine__pb2.StreamExportCsvEntityReportRequest.FromString,
            response_serializer=szengine__pb2.StreamExportCsvEntityReportResponse.SerializeToString,
        ),
        "StreamExportJsonEntityReport": grpc.unary_stream_rpc_method_handler(
            servicer.StreamExportJsonEntityReport,
            request_deserializer=szengine__pb2.StreamExportJsonEntityReportRequest.FromString,
            response_serializer=szengine__pb2.StreamExportJsonEntityReportResponse.SerializeToString,
        ),
        "WhyEntities": grpc.unary_unary_rpc_method_handler(
            servicer.WhyEntities,
            request_deserializer=szengine__pb2.WhyEntitiesRequest.FromString,
            response_serializer=szengine__pb2.WhyEntitiesResponse.SerializeToString,
        ),
        "WhyRecordInEntity": grpc.unary_unary_rpc_method_handler(
            servicer.WhyRecordInEntity,
            request_deserializer=szengine__pb2.WhyRecordInEntityRequest.FromString,
            response_serializer=szengine__pb2.WhyRecordInEntityResponse.SerializeToString,
        ),
        "WhyRecords": grpc.unary_unary_rpc_method_handler(
            servicer.WhyRecords,
            request_deserializer=szengine__pb2.WhyRecordsRequest.FromString,
            response_serializer=szengine__pb2.WhyRecordsResponse.SerializeToString,
        ),
        "WhySearch": grpc.unary_unary_rpc_method_handler(
            servicer.WhySearch,
            request_deserializer=szengine__pb2.WhySearchRequest.FromString,
            response_serializer=szengine__pb2.WhySearchResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("szengine.SzEngine", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("szengine.SzEngine", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class SzEngine(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/AddRecord",
            szengine__pb2.AddRecordRequest.SerializeToString,
            szengine__pb2.AddRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def CloseExport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/CloseExport",
            szengine__pb2.CloseExportRequest.SerializeToString,
            szengine__pb2.CloseExportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def CountRedoRecords(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/CountRedoRecords",
            szengine__pb2.CountRedoRecordsRequest.SerializeToString,
            szengine__pb2.CountRedoRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def DeleteRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/DeleteRecord",
            szengine__pb2.DeleteRecordRequest.SerializeToString,
            szengine__pb2.DeleteRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ExportCsvEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/ExportCsvEntityReport",
            szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.ExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ExportJsonEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/ExportJsonEntityReport",
            szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.ExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FetchNext(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FetchNext",
            szengine__pb2.FetchNextRequest.SerializeToString,
            szengine__pb2.FetchNextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindInterestingEntitiesByEntityId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindInterestingEntitiesByEntityId",
            szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindInterestingEntitiesByRecordId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindInterestingEntitiesByRecordId",
            szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindNetworkByEntityId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindNetworkByEntityId",
            szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindNetworkByRecordId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindNetworkByRecordId",
            szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindPathByEntityId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindPathByEntityId",
            szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
            szengine__pb2.FindPathByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def FindPathByRecordId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/FindPathByRecordId",
            szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
            szengine__pb2.FindPathByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetActiveConfigId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetActiveConfigId",
            szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
            szengine__pb2.GetActiveConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetEntityByEntityId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetEntityByEntityId",
            szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.GetEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetEntityByRecordId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetEntityByRecordId",
            szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetRecord",
            szengine__pb2.GetRecordRequest.SerializeToString,
            szengine__pb2.GetRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetRedoRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetRedoRecord",
            szengine__pb2.GetRedoRecordRequest.SerializeToString,
            szengine__pb2.GetRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetStats(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetStats",
            szengine__pb2.GetStatsRequest.SerializeToString,
            szengine__pb2.GetStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetVirtualEntityByRecordId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/GetVirtualEntityByRecordId",
            szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def HowEntityByEntityId(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/HowEntityByEntityId",
            szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.HowEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def PreprocessRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/PreprocessRecord",
            szengine__pb2.PreprocessRecordRequest.SerializeToString,
            szengine__pb2.PreprocessRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def PrimeEngine(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/PrimeEngine",
            szengine__pb2.PrimeEngineRequest.SerializeToString,
            szengine__pb2.PrimeEngineResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ProcessRedoRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/ProcessRedoRecord",
            szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
            szengine__pb2.ProcessRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ReevaluateEntity(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/ReevaluateEntity",
            szengine__pb2.ReevaluateEntityRequest.SerializeToString,
            szengine__pb2.ReevaluateEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ReevaluateRecord(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/ReevaluateRecord",
            szengine__pb2.ReevaluateRecordRequest.SerializeToString,
            szengine__pb2.ReevaluateRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Reinitialize(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/Reinitialize",
            szengine__pb2.ReinitializeRequest.SerializeToString,
            szengine__pb2.ReinitializeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SearchByAttributes(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/SearchByAttributes",
            szengine__pb2.SearchByAttributesRequest.SerializeToString,
            szengine__pb2.SearchByAttributesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamExportCsvEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/szengine.SzEngine/StreamExportCsvEntityReport",
            szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def StreamExportJsonEntityReport(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/szengine.SzEngine/StreamExportJsonEntityReport",
            szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def WhyEntities(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/WhyEntities",
            szengine__pb2.WhyEntitiesRequest.SerializeToString,
            szengine__pb2.WhyEntitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def WhyRecordInEntity(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/WhyRecordInEntity",
            szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
            szengine__pb2.WhyRecordInEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def WhyRecords(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/WhyRecords",
            szengine__pb2.WhyRecordsRequest.SerializeToString,
            szengine__pb2.WhyRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def WhySearch(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/szengine.SzEngine/WhySearch",
            szengine__pb2.WhySearchRequest.SerializeToString,
            szengine__pb2.WhySearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szengine.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szengine.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eszengine.proto\x12\x08szengine\"i\n\x10\x41\x64\x64RecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\x19\n\x11record_definition\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03\"#\n\x11\x41\x64\x64RecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"+\n\x12\x43loseExportRequest\x12\x15\n\rexport_handle\x18\x01 \x01(\x03\"\x15\n\x13\x43loseExportResponse\"\x19\n\x17\x43ountRedoRecordsRequest\"*\n\x18\x43ountRedoRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"Q\n\x13\x44\x65leteRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"&\n\x14\x44\x65leteRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"F\n\x1c\x45xportCsvEntityReportRequest\x12\x17\n\x0f\x63sv_column_list\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"/\n\x1d\x45xportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\".\n\x1d\x45xportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"0\n\x1e\x45xportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\")\n\x10\x46\x65tchNextRequest\x12\x15\n\rexport_handle\x18\x01 \x01(\x03\"#\n\x11\x46\x65tchNextResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"L\n(FindInterestingEntitiesByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\";\n)FindInterestingEntitiesByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"f\n(FindInterestingEntitiesByRecordIdRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\";\n)FindInterestingEntitiesByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x91\x01\n\x1c\x46indNetworkByEntityIdRequest\x12\x12\n\nentity_ids\x18\x01 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x02 \x01(\x03\x12\x19\n\x11\x62uild_out_degrees\x18\x03 \x01(\x03\x12\x1e\n\x16\x62uild_out_max_entities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x92\x01\n\x1c\x46indNetworkByRecordIdRequest\x12\x13\n\x0brecord_keys\x18\x01 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x02 \x01(\x03\x12\x19\n\x11\x62uild_out_degrees\x18\x03 \x01(\x03\x12\x1e\n\x16\x62uild_out_max_entities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\xa8\x01\n\x19\x46indPathByEntityIdRequest\x12\x17\n\x0fstart_entity_id\x18\x01 \x01(\x03\x12\x15\n\rend_entity_id\x18\x02 \x01(\x03\x12\x13\n\x0bmax_degrees\x18\x03 \x01(\x03\x12\x18\n\x10\x61void_entity_ids\x18\x04 \x01(\t\x12\x1d\n\x15required_data_sources\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03\",\n\x1a\x46indPathByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\xe7\x01\n\x19\x46indPathByRecordIdRequest\x12\x1e\n\x16start_data_source_code\x18\x01 \x01(\t\x12\x17\n\x0fstart_record_id\x18\x02 \x01(\t\x12\x1c\n\x14\x65nd_data_source_code\x18\x03 \x01(\t\x12\x15\n\rend_record_id\x18\x04 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x05 \x01(\x03\x12\x19\n\x11\x61void_record_keys\x18\x06 \x01(\t\x12\x1d\n\x15required_data_sources\x18\x07 \x01(\t\x12\r\n\x05\x66lags\x18\x08 \x01(\x03\",\n\x1a\x46indPathByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1a\n\x18GetActiveConfigIdRequest\"+\n\x19GetActiveConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\">\n\x1aGetEntityByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bGetEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"X\n\x1aGetEntityByRecordIdRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"-\n\x1bGetEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"N\n\x10GetRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"#\n\x11GetRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x16\n\x14GetRedoRecordRequest\"\'\n\x15GetRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x11\n\x0fGetStatsRequest\"\"\n\x10GetStatsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"G\n!GetVirtualEntityByRecordIdRequest\x12\x13\n\x0brecord_keys\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"4\n\"GetVirtualEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\">\n\x1aHowEntityByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bHowEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"C\n\x17PreprocessRecordRequest\x12\x19\n\x11record_definition\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18PreprocessRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x14\n\x12PrimeEngineRequest\"\x15\n\x13PrimeEngineResponse\">\n\x18ProcessRedoRecordRequest\x12\x13\n\x0bredo_record\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"+\n\x19ProcessRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\";\n\x17ReevaluateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18ReevaluateEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"U\n\x17ReevaluateRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"*\n\x18ReevaluateRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"(\n\x13ReinitializeRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"\x16\n\x14ReinitializeResponse\"V\n\x19SearchByAttributesRequest\x12\x12\n\nattributes\x18\x01 \x01(\t\x12\x16\n\x0esearch_profile\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\",\n\x1aSearchByAttributesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"L\n\"StreamExportCsvEntityReportRequest\x12\x17\n\x0f\x63sv_column_list\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"5\n#StreamExportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"4\n#StreamExportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"6\n$StreamExportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"M\n\x12WhyEntitiesRequest\x12\x13\n\x0b\x65ntity_id_1\x18\x01 \x01(\x03\x12\x13\n\x0b\x65ntity_id_2\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"%\n\x13WhyEntitiesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"V\n\x18WhyRecordInEntityRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"+\n\x19WhyRecordInEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x84\x01\n\x11WhyRecordsRequest\x12\x1a\n\x12\x64\x61ta_source_code_1\x18\x01 \x01(\t\x12\x13\n\x0brecord_id_1\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_source_code_2\x18\x03 \x01(\t\x12\x13\n\x0brecord_id_2\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"$\n\x12WhyRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"`\n\x10WhySearchRequest\x12\x12\n\nattributes\x18\x01 \x01(\t\x12\x11\n\tentity_id\x18\x02 \x01(\x03\x12\x16\n\x0esearch_profile\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03\"#\n\x11WhySearchResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\xdd\x19\n\x08SzEngine\x12\x46\n\tAddRecord\x12\x1a.szengine.AddRecordRequest\x1a\x1b.szengine.AddRecordResponse\"\x00\x12L\n\x0b\x43loseExport\x12\x1c.szengine.CloseExportRequest\x1a\x1d.szengine.CloseExportResponse\"\x00\x12[\n\x10\x43ountRedoRecords\x12!.szengine.CountRedoRecordsRequest\x1a\".szengine.CountRedoRecordsResponse\"\x00\x12O\n\x0c\x44\x65leteRecord\x12\x1d.szengine.DeleteRecordRequest\x1a\x1e.szengine.DeleteRecordResponse\"\x00\x12j\n\x15\x45xportCsvEntityReport\x12&.szengine.ExportCsvEntityReportRequest\x1a\'.szengine.ExportCsvEntityReportResponse\"\x00\x12m\n\x16\x45xportJsonEntityReport\x12\'.szengine.ExportJsonEntityReportRequest\x1a(.szengine.ExportJsonEntityReportResponse\"\x00\x12\x46\n\tFetchNext\x12\x1a.szengine.FetchNextRequest\x1a\x1b.szengine.FetchNextResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByEntityId\x12\x32.szengine.FindInterestingEntitiesByEntityIdRequest\x1a\x33.szengine.FindInterestingEntitiesByEntityIdResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByRecordId\x12\x32.szengine.FindInterestingEntitiesByRecordIdRequest\x1a\x33.szengine.FindInterestingEntitiesByRecordIdResponse\"\x00\x12j\n\x15\x46indNetworkByEntityId\x12&.szengine.FindNetworkByEntityIdRequest\x1a\'.szengine.FindNetworkByEntityIdResponse\"\x00\x12j\n\x15\x46indNetworkByRecordId\x12&.szengine.FindNetworkByRecordIdRequest\x1a\'.szengine.FindNetworkByRecordIdResponse\"\x00\x12\x61\n\x12\x46indPathByEntityId\x12#.szengine.FindPathByEntityIdRequest\x1a$.szengine.FindPathByEntityIdResponse\"\x00\x12\x61\n\x12\x46indPathByRecordId\x12#.szengine.FindPathByRecordIdRequest\x1a$.szengine.FindPathByRecordIdResponse\"\x00\x12^\n\x11GetActiveConfigId\x12\".szengine.GetActiveConfigIdRequest\x1a#.szengine.GetActiveConfigIdResponse\"\x00\x12\x64\n\x13GetEntityByEntityId\x12$.szengine.GetEntityByEntityIdRequest\x1a%.szengine.GetEntityByEntityIdResponse\"\x00\x12\x64\n\x13GetEntityByRecordId\x12$.szengine.GetEntityByRecordIdRequest\x1a%.szengine.GetEntityByRecordIdResponse\"\x00\x12\x46\n\tGetRecord\x12\x1a.szengine.GetRecordRequest\x1a\x1b.szengine.GetRecordResponse\"\x00\x12R\n\rGetRedoRecord\x12\x1e.szengine.GetRedoRecordRequest\x1a\x1f.szengine.GetRedoRecordResponse\"\x00\x12\x43\n\x08GetStats\x12\x19.szengine.GetStatsRequest\x1a\x1a.szengine.GetStatsResponse\"\x00\x12y\n\x1aGetVirtualEntityByRecordId\x12+.szengine.GetVirtualEntityByRecordIdRequest\x1a,.szengine.GetVirtualEntityByRecordIdResponse\"\x00\x12\x64\n\x13HowEntityByEntityId\x12$.szengine.HowEntityByEntityIdRequest\x1a%.szengine.HowEntityByEntityIdResponse\"\x00\x12[\n\x10PreprocessRecord\x12!.szengine.PreprocessRecordRequest\x1a\".szengine.PreprocessRecordResponse\"\x00\x12L\n\x0bPrimeEngine\x12\x1c.szengine.PrimeEngineRequest\x1a\x1d.szengine.PrimeEngineResponse\"\x00\x12^\n\x11ProcessRedoRecord\x12\".szengine.ProcessRedoRecordRequest\x1a#.szengine.ProcessRedoRecordResponse\"\x00\x12[\n\x10ReevaluateEntity\x12!.szengine.ReevaluateEntityRequest\x1a\".szengine.ReevaluateEntityResponse\"\x00\x12[\n\x10ReevaluateRecord\x12!.szengine.ReevaluateRecordRequest\x1a\".szengine.ReevaluateRecordResponse\"\x00\x12O\n\x0cReinitialize\x12\x1d.szengine.ReinitializeRequest\x1a\x1e.szengine.ReinitializeResponse\"\x00\x12\x61\n\x12SearchByAttributes\x12#.szengine.SearchByAttributesRequest\x1a$.szengine.SearchByAttributesResponse\"\x00\x12~\n\x1bStreamExportCsvEntityReport\x12,.szengine.StreamExportCsvEntityReportRequest\x1a-.szengine.StreamExportCsvEntityReportResponse\"\x00\x30\x01\x12\x81\x01\n\x1cStreamExportJsonEntityReport\x12-.szengine.StreamExportJsonEntityReportRequest\x1a..szengine.StreamExportJsonEntityReportResponse\"\x00\x30\x01\x12L\n\x0bWhyEntities\x12\x1c.szengine.WhyEntitiesRequest\x1a\x1d.szengine.WhyEntitiesResponse\"\x00\x12^\n\x11WhyRecordInEntity\x12\".szengine.WhyRecordInEntityRequest\x1a#.szengine.WhyRecordInEntityResponse\"\x00\x12I\n\nWhyRecords\x12\x1b.szengine.WhyRecordsRequest\x1a\x1c.szengine.WhyRecordsResponse\"\x00\x12\x46\n\tWhySearch\x12\x1a.szengine.WhySearchRequest\x1a\x1b.szengine.WhySearchResponse\"\x00\x42X\n\x14\x63om.senzing.sdk.grpcB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szengine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengine'
  _globals['_ADDRECORDREQUEST']._serialized_start=28
  _globals['_ADDRECORDREQUEST']._serialized_end=133
  _globals['_ADDRECORDRESPONSE']._serialized_start=135
  _globals['_ADDRECORDRESPONSE']._serialized_end=170
  _globals['_CLOSEEXPORTREQUEST']._serialized_start=172
  _globals['_CLOSEEXPORTREQUEST']._serialized_end=215
  _globals['_CLOSEEXPORTRESPONSE']._serialized_start=217
  _globals['_CLOSEEXPORTRESPONSE']._serialized_end=238
  _globals['_COUNTREDORECORDSREQUEST']._serialized_start=240
  _globals['_COUNTREDORECORDSREQUEST']._serialized_end=265
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_start=267
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_end=309
  _globals['_DELETERECORDREQUEST']._serialized_start=311
  _globals['_DELETERECORDREQUEST']._serialized_end=392
  _globals['_DELETERECORDRESPONSE']._serialized_start=394
  _globals['_DELETERECORDRESPONSE']._serialized_end=432
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_start=434
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_end=504
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_start=506
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_end=553
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_start=555
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_end=601
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_start=603
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_end=651
  _globals['_FETCHNEXTREQUEST']._serialized_start=653
  _globals['_FETCHNEXTREQUEST']._serialized_end=694
  _globals['_FETCHNEXTRESPONSE']._serialized_start=696
  _globals['_FETCHNEXTRESPONSE']._serialized_end=731
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_start=733
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_end=809
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_start=811
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_end=870
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_start=872
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_end=974
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_start=976
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_end=1035
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_start=1038
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_end=1183
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_start=1185
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_end=1232
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_start=1235
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_end=1381
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_start=1383
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_end=1430
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_start=1433
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_end=1601
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_start=1603
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_end=1647
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_start=1650
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_end=1881
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_start=1883
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_end=1927
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_start=1929
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_end=1955
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_start=1957
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_end=2000
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_start=2002
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_end=2064
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_start=2066
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_end=2111
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_start=2113
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_end=2201
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_start=2203
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_end=2248
  _globals['_GETRECORDREQUEST']._serialized_start=2250
  _globals['_GETRECORDREQUEST']._serialized_end=2328
  _globals['_GETRECORDRESPONSE']._serialized_start=2330
  _globals['_GETRECORDRESPONSE']._serialized_end=2365
  _globals['_GETREDORECORDREQUEST']._serialized_start=2367
  _globals['_GETREDORECORDREQUEST']._serialized_end=2389
  _globals['_GETREDORECORDRESPONSE']._serialized_start=2391
  _globals['_GETREDORECORDRESPONSE']._serialized_end=2430
  _globals['_GETSTATSREQUEST']._serialized_start=2432
  _globals['_GETSTATSREQUEST']._serialized_end=2449
  _globals['_GETSTATSRESPONSE']._serialized_start=2451
  _globals['_GETSTATSRESPONSE']._serialized_end=2485
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_start=2487
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_end=2558
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_start=2560
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_end=2612
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_start=2614
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_end=2676
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_start=2678
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_end=2723
  _globals['_PREPROCESSRECORDREQUEST']._serialized_start=2725
  _globals['_PREPROCESSRECORDREQUEST']._serialized_end=2792
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_start=2794
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_end=2836
  _globals['_PRIMEENGINEREQUEST']._serialized_start=2838
  _globals['_PRIMEENGINEREQUEST']._serialized_end=2858
  _globals['_PRIMEENGINERESPONSE']._serialized_start=2860
  _globals['_PRIMEENGINERESPONSE']._serialized_end=2881
  _globals['_PROCESSREDORECORDREQUEST']._serialized_start=2883
  _globals['_PROCESSREDORECORDREQUEST']._serialized_end=2945
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_start=2947
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_end=2990
  _globals['_REEVALUATEENTITYREQUEST']._serialized_start=2992
  _globals['_REEVALUATEENTITYREQUEST']._serialized_end=3051
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_start=3053
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_end=3095
  _globals['_REEVALUATERECORDREQUEST']._serialized_start=3097
  _globals['_REEVALUATERECORDREQUEST']._serialized_end=3182
  _globals['_REEVALUATERECORDRESPONSE']._serialized_start=3184
  _globals['_REEVALUATERECORDRESPONSE']._serialized_end=3226
  _globals['_REINITIALIZEREQUEST']._serialized_start=3228
  _globals['_REINITIALIZEREQUEST']._serialized_end=3268
  _globals['_REINITIALIZERESPONSE']._serialized_start=3270
  _globals['_REINITIALIZERESPONSE']._serialized_end=3292
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_start=3294
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_end=3380
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_start=3382
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_end=3426
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_start=3428
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_end=3504
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_start=3506
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_end=3559
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_start=3561
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_end=3613
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_start=3615
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_end=3669
  _globals['_WHYENTITIESREQUEST']._serialized_start=3671
  _globals['_WHYENTITIESREQUEST']._serialized_end=3748
  _globals['_WHYENTITIESRESPONSE']._serialized_start=3750
  _globals['_WHYENTITIESRESPONSE']._serialized_end=3787
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_start=3789
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_end=3875
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_start=3877
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_end=3920
  _globals['_WHYRECORDSREQUEST']._serialized_start=3923
  _globals['_WHYRECORDSREQUEST']._serialized_end=4055
  _globals['_WHYRECORDSRESPONSE']._serialized_start=4057
  _globals['_WHYRECORDSRESPONSE']._serialized_end=4093
  _globals['_WHYSEARCHREQUEST']._serialized_start=4095
  _globals['_WHYSEARCHREQUEST']._serialized_end=4191
  _globals['_WHYSEARCHRESPONSE']._serialized_start=4193
  _globals['_WHYSEARCHRESPONSE']._serialized_end=4228
  _globals['_SZENGINE']._serialized_start=4231
  _globals['_SZENGINE']._serialized_end=7524
# @@protoc_insertion_point(module_scope)
